@@ -1,6 +1,7 @@
 import click
 
-from cli.utils import Spotify
+from ..utils import Spotify
+from ..utils.exceptions import NoPlaybackError
 
 
 @click.command(name='next', options_metavar='[<options>]')
@@ -13,8 +14,11 @@ from cli.utils import Spotify
     help='Suppress output.'
 )
 def _next(verbose=0, quiet=False):
-    """Play the next song in the queue."""
-    Spotify.request('me/player/next', method='POST')
+    """Play the next track in the queue."""
+    Spotify.request(
+        'me/player/next', method='POST',
+        handle_errs={404: NoPlaybackError}
+    )
     if not quiet:
         from cli.commands.status import status
         status.callback(verbose=verbose)
