@@ -1,6 +1,7 @@
 import click
 
-from cli.utils import Spotify
+from ..utils import Spotify
+from ..utils.exceptions import NoPlaybackError
 
 
 @click.command(options_metavar='[<options>]')
@@ -18,8 +19,12 @@ from cli.utils import Spotify
 def shuffle(mode, verbose=0, quiet=False, _create_request=False):
     """Turn shuffle on or off."""
     request = {
-        'endpoint': 'me/player/shuffle?state={}'.format('true' if mode == 'on' else 'false'),
-        'method': 'PUT'
+        'endpoint': (
+            'me/player/shuffle?state={}'
+            .format('true' if mode == 'on' else 'false')
+        ),
+        'method': 'PUT',
+        'handle_errs': {404: NoPlaybackError},
     }
     if _create_request:
         return request
@@ -32,6 +37,9 @@ def shuffle(mode, verbose=0, quiet=False, _create_request=False):
         click.echo('Shuffle turned {}.'.format(mode))
     else:
         from cli.commands.status import status
-        status.callback(verbose=verbose, _override={'is_shuffle': mode == 'on'})
+        status.callback(
+            verbose=verbose,
+            _override={'is_shuffle': mode == 'on'}
+        )
 
     return
